module Godmode
  module Generators
    module OrmHelpers
      def needs_attr_accessible?
        rails_3? && !strong_parameters_enabled?
      end

      def rails_3?
        Rails::VERSION::MAJOR == 3
      end

      def strong_parameters_enabled?
        defined?(ActionController::StrongParameters)
      end

      private

      def migration src, dest
        unless migration_exists? dest
          migration_template src, "db/migrate/gdd_#{dest}.rb"
          rake "db:migrate"
        end
      end

      def model_exists?
        File.exists?(File.join(destination_root, model_path))
      end

      def migration_exists?(name)
        Dir.glob("#{File.join(destination_root, migration_path)}/[0-9]*_*.rb").grep(/\d+_gdd_#{name}.rb$/).first
      end

      def migration_path
        @migration_path ||= File.join("db", "migrate")
      end

      def model_path
        @model_path ||= File.join("app", "models", "#{file_path}.rb")
      end
    end
  end
end
